==> scotch_5.1.12b.dfsg.orig.tar.gz: scotch-5.1.12b.dfsg/src/libscotch/library_dgraph_order_tree_dist_f.c <==
/* Copyright 2007 ENSEIRB, INRIA & CNRS
**
** This file is part of the Scotch software package for static mapping,
** graph partitioning and sparse matrix ordering.
**
** This software is governed by the CeCILL-C license under French law
** and abiding by the rules of distribution of free software. You can
** use, modify and/or redistribute the software under the terms of the
** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
** URL: "http://www.cecill.info".
** 
** As a counterpart to the access to the source code and rights to copy,
** modify and redistribute granted by the license, users are provided
** only with a limited warranty and the software's author, the holder of
** the economic rights, and the successive licensors have only limited
** liability.
** 
** In this respect, the user's attention is drawn to the risks associated
** with loading, using, modifying and/or developing or reproducing the
** software by the user in light of its specific status of free software,
** that may mean that it is complicated to manipulate, and that also
** therefore means that it is reserved for developers and experienced
** professionals having in-depth computer knowledge. Users are therefore
** encouraged to load and test the software's suitability as regards
** their requirements in conditions enabling the security of their
** systems and/or data to be ensured and, more generally, to use and
** operate it in the same conditions as regards security.
** 
** The fact that you are presently reading this means that you have had
** knowledge of the CeCILL-C license and that you accept its terms.
*/
/************************************************************/
/**                                                        **/
/**   NAME       : library_dgraph_order_tree_dist_f.c      **/
/**                                                        **/
/**   AUTHOR     : Francois PELLEGRINI                     **/
/**                                                        **/
/**   FUNCTION   : This module is the Fortran API for the  **/
/**                distributed ordering distributed tree   **/
/**                building routine of the libSCOTCH       **/
/**                library.                                **/
/**                                                        **/
/**   DATES      : # Version 5.1  : from : 30 nov 2007     **/
/**                                 to     30 nov 2007     **/
/**                                                        **/
/************************************************************/

/*
**  The defines and includes.
*/

#define LIBRARY

#include "module.h"
#include "common.h"
#include "scotch.h"

/**************************************/
/*                                    */
/* These routines are the Fortran API */
/* for the ordering routines.         */
/*                                    */
/**************************************/

FORTRAN (                                                 \
SCOTCHFDGRAPHORDERCBLKDIST, scotchfdgraphordercblkdist, ( \
const SCOTCH_Dgraph * const     grafptr,                  \
const SCOTCH_Dordering * const  ordeptr,                  \
SCOTCH_Num * const              cblkglbptr),
(grafptr, ordeptr, cblkglbptr))
{
  *cblkglbptr = SCOTCH_dgraphOrderCblkDist (grafptr, ordeptr);
}

/*
**
*/

FORTRAN (                                                 \
SCOTCHFDGRAPHORDERTREEDIST, scotchfdgraphordertreedist, ( \
const SCOTCH_Dgraph * const     grafptr,                  \
const SCOTCH_Dordering * const  ordeptr,                  \
SCOTCH_Num * const              treeglbtab,               \
SCOTCH_Num * const              sizeglbtab,               \
int * const                     revaptr),                 \
(grafptr, ordeptr, treeglbtab, sizeglbtab, revaptr))
{
  *revaptr = SCOTCH_dgraphOrderTreeDist (grafptr, ordeptr, treeglbtab, sizeglbtab);
}

==> scotch_6.0.6.orig.tar.gz: scotch_6.0.6/src/libscotch/library_dgraph_order_tree_dist_f.c <==
/* Copyright 2007,2012,2018 IPB, Universite de Bordeaux, INRIA & CNRS
**
** This file is part of the Scotch software package for static mapping,
** graph partitioning and sparse matrix ordering.
**
** This software is governed by the CeCILL-C license under French law
** and abiding by the rules of distribution of free software. You can
** use, modify and/or redistribute the software under the terms of the
** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
** URL: "http://www.cecill.info".
** 
** As a counterpart to the access to the source code and rights to copy,
** modify and redistribute granted by the license, users are provided
** only with a limited warranty and the software's author, the holder of
** the economic rights, and the successive licensors have only limited
** liability.
** 
** In this respect, the user's attention is drawn to the risks associated
** with loading, using, modifying and/or developing or reproducing the
** software by the user in light of its specific status of free software,
** that may mean that it is complicated to manipulate, and that also
** therefore means that it is reserved for developers and experienced
** professionals having in-depth computer knowledge. Users are therefore
** encouraged to load and test the software's suitability as regards
** their requirements in conditions enabling the security of their
** systems and/or data to be ensured and, more generally, to use and
** operate it in the same conditions as regards security.
** 
** The fact that you are presently reading this means that you have had
** knowledge of the CeCILL-C license and that you accept its terms.
*/
/************************************************************/
/**                                                        **/
/**   NAME       : library_dgraph_order_tree_dist_f.c      **/
/**                                                        **/
/**   AUTHOR     : Francois PELLEGRINI                     **/
/**                                                        **/
/**   FUNCTION   : This module is the Fortran API for the  **/
/**                distributed ordering distributed tree   **/
/**                building routine of the libSCOTCH       **/
/**                library.                                **/
/**                                                        **/
/**   DATES      : # Version 5.1  : from : 30 nov 2007     **/
/**                                 to     30 nov 2007     **/
/**                # Version 6.0  : from : 29 nov 2012     **/
/**                                 to     25 apr 2018     **/
/**                                                        **/
/************************************************************/

/*
**  The defines and includes.
*/

#define LIBRARY

#include "module.h"
#include "common.h"
#include "ptscotch.h"

/**************************************/
/*                                    */
/* These routines are the Fortran API */
/* for the ordering routines.         */
/*                                    */
/**************************************/

SCOTCH_FORTRAN (                            \
DGRAPHORDERCBLKDIST, dgraphordercblkdist, ( \
SCOTCH_Dgraph * const       grafptr,        \
SCOTCH_Dordering * const    ordeptr,        \
SCOTCH_Num * const          cblkglbptr),    \
(grafptr, ordeptr, cblkglbptr))
{
  *cblkglbptr = SCOTCH_dgraphOrderCblkDist (grafptr, ordeptr);
}

/*
**
*/

SCOTCH_FORTRAN (                            \
DGRAPHORDERTREEDIST, dgraphordertreedist, ( \
SCOTCH_Dgraph * const       grafptr,        \
SCOTCH_Dordering * const    ordeptr,        \
SCOTCH_Num * const          treeglbtab,     \
SCOTCH_Num * const          sizeglbtab,     \
int * const                 revaptr),       \
(grafptr, ordeptr, treeglbtab, sizeglbtab, revaptr))
{
  *revaptr = SCOTCH_dgraphOrderTreeDist (grafptr, ordeptr, treeglbtab, sizeglbtab);
}
